@@ -1,5 +1,5 @@
 from bgameb.game import Game
-from bgameb.utils import log_enable
+from bgameb.base import log_enable
 from bgameb._version import __version__
 
 
