@@ -1,10 +1,9 @@
 """Base constructs for build package objects
 """
-from abc import ABC
 from typing import Dict, List, Optional, Any, Iterator
 from collections.abc import Mapping
 from dataclasses import dataclass, field, make_dataclass
-from dataclasses_json import DataClassJsonMixin
+from dataclasses_json import DataClassJsonMixin, config
 from bgameb.errors import ComponentNameError
 from loguru import logger
 
@@ -162,8 +161,8 @@ class Components(Mapping, DataClassJsonMixin):
 
 
 @dataclass
-class Base(Components, DataClassJsonMixin, ABC):
-    """Base class for game, stuff and tools
+class Base(Components, DataClassJsonMixin):
+    """Base class for game, stuff, tools players and other components
     """
     name: str
     is_active: bool = True
