@@ -2,13 +2,13 @@
 """
 from typing import Optional, Literal, List
 from collections import Counter
-from abc import ABC
 from dataclasses import dataclass, field
+from dataclasses_json import config
 from bgameb.base import Base
 
 
 @dataclass
-class BasePlayer(Base, ABC):
+class BasePlayer(Base):
     """Base class for game players and bots
 
     Attrs
@@ -41,12 +41,17 @@ class BasePlayer(Base, ABC):
 class Player(BasePlayer):
     """Base class to create a player
     """
+    type_: str = field(
+        default='player',
+        metadata=config(exclude=lambda x: True),  # type: ignore
+        repr=False
+        )
 
     def __post_init__(self) -> None:
         super().__post_init__()
 
 
 PLAYERS = {
-    'player': Player,
+    Player.type_: Player,
     }
 PLAERS_TYPES = Literal['player', ]
